@@ -2,9 +2,10 @@
 
 .onLoad <- function(...) {
   reset.spatstat.options()
-  umf <- system.file("doc", "umbrella.txt", package="spatstat")
-  isum <- !is.null(umf) && file.exists(umf)
-  putSpatstatVariable("Spatstat.Is.Umbrella", isum)
+  ##  umf <- system.file("doc", "umbrella.txt", package="spatstat")
+  ##  isum <- !is.null(umf) && file.exists(umf)
+  ##  putSpatstatVariable("Spatstat.Is.Umbrella", isum)
+  putSpatstatVariable("Spatstat.Is.Umbrella", TRUE)
   invisible(NULL)
 }
 .onAttach <- function(libname, pkgname) {
@@ -12,11 +13,11 @@
                  fields="Version")
   vs <- as.character(vs)
   putSpatstatVariable("SpatstatVersion", vs)
-  nickfile <- system.file("doc", "Nickname.txt", package="spatstat")
-  ni <- scan(file=nickfile, what=character(), n=1, quiet=TRUE)
+##  nickfile <- system.file("doc", "Nickname.txt", package="spatstat")
+##  ni <- scan(file=nickfile, what=character(), n=1, quiet=TRUE)
   msg <- paste("\nspatstat", vs,
-               "     ",
-               paren(paste("nickname:", sQuote(ni))),
+##               "     ",
+##               paren(paste("nickname:", sQuote(ni))),
                "\nFor an introduction to spatstat, type",
                sQuote("beginner"), "\n")
   packageStartupMessage(msg)
